@@ -18,9 +18,7 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include "gedit-app.h"
 #include "gedit-app-private.h"
@@ -30,9 +28,8 @@
 #include <stdlib.h>
 
 #include <glib/gi18n.h>
-#include <gio/gio.h>
 #include <libpeas/peas-extension-set.h>
-#include <gtksourceview/gtksource.h>
+#include <tepl/tepl.h>
 
 #ifdef ENABLE_INTROSPECTION
 #include <girepository.h>
@@ -52,10 +49,6 @@
 #include "gedit-tab.h"
 #include "gedit-tab-private.h"
 
-#ifndef ENABLE_GVFS_METADATA
-#include "gedit-metadata-manager.h"
-#endif
-
 #define GEDIT_PAGE_SETUP_FILE		"gedit-page-setup"
 #define GEDIT_PRINT_SETTINGS_FILE	"gedit-print-settings"
 
@@ -63,10 +56,6 @@ typedef struct
 {
 	GeditPluginsEngine *engine;
 
-#ifndef ENABLE_GVFS_METADATA
-	GeditMetadataManager *metadata_manager;
-#endif
-
 	GtkCssProvider     *theme_provider;
 
 	GeditLockdownMask  lockdown;
@@ -174,10 +163,6 @@ gedit_app_dispose (GObject *object)
 
 	priv = gedit_app_get_instance_private (GEDIT_APP (object));
 
-#ifndef ENABLE_GVFS_METADATA
-	g_clear_object (&priv->metadata_manager);
-#endif
-
 	g_clear_object (&priv->ui_settings);
 	g_clear_object (&priv->window_settings);
 	g_clear_object (&priv->settings);
@@ -255,11 +240,6 @@ gedit_app_show_help_impl (GeditApp    *app,
 	{
 		name = "gedit";
 	}
-	else if (strcmp (name, "gedit.xml") == 0)
-	{
-		g_warning ("%s: Using \"gedit.xml\" for the help name is deprecated, use \"gedit\" or simply NULL instead", G_STRFUNC);
-		name = "gedit";
-	}
 
 	link = GEDIT_APP_GET_CLASS (app)->help_link_id (app, name, link_id);
 
@@ -758,16 +738,26 @@ show_menubar (void)
 	return result;
 }
 
+static void
+setup_metadata_manager (void)
+{
+	const gchar *user_data_dir;
+	gchar *metadata_path;
+
+	user_data_dir = gedit_dirs_get_user_data_dir ();
+	metadata_path = g_build_filename (user_data_dir, "gedit-metadata.xml", NULL);
+
+	tepl_metadata_manager_init (metadata_path);
+
+	g_free (metadata_path);
+}
+
 static void
 gedit_app_startup (GApplication *application)
 {
 	GeditAppPrivate *priv;
 	GtkCssProvider *css_provider;
 	GtkSourceStyleSchemeManager *manager;
-#ifndef ENABLE_GVFS_METADATA
-	const gchar *cache_dir;
-	gchar *metadata_filename;
-#endif
 
 	priv = gedit_app_get_instance_private (GEDIT_APP (application));
 
@@ -777,14 +767,9 @@ gedit_app_startup (GApplication *application)
 	gedit_debug_init ();
 	gedit_debug_message (DEBUG_APP, "Startup");
 
-	setup_theme_extensions (GEDIT_APP (application));
+	setup_metadata_manager ();
 
-#ifndef ENABLE_GVFS_METADATA
-	cache_dir = gedit_dirs_get_user_cache_dir ();
-	metadata_filename = g_build_filename (cache_dir, "gedit-metadata.xml", NULL);
-	priv->metadata_manager = gedit_metadata_manager_new (metadata_filename);
-	g_free (metadata_filename);
-#endif
+	setup_theme_extensions (GEDIT_APP (application));
 
 	/* Load settings */
 	priv->settings = gedit_settings_new ();
@@ -1248,10 +1233,6 @@ gedit_app_shutdown (GApplication *app)
 	save_page_setup (GEDIT_APP (app));
 	save_print_settings (GEDIT_APP (app));
 
-	/* GTK+ can still hold references to some gedit objects, for example
-	 * GeditDocument for the clipboard. So the metadata-manager should be
-	 * shutdown after.
-	 */
 	G_APPLICATION_CLASS (gedit_app_parent_class)->shutdown (app);
 
 	gedit_dirs_shutdown ();
@@ -1875,24 +1856,6 @@ _gedit_app_get_settings (GeditApp *app)
 	return priv->settings;
 }
 
-GeditMetadataManager *
-_gedit_app_get_metadata_manager (GeditApp *app)
-{
-#ifndef ENABLE_GVFS_METADATA
-	GeditAppPrivate *priv;
-
-	g_return_val_if_fail (GEDIT_IS_APP (app), NULL);
-
-	priv = gedit_app_get_instance_private (app);
-
-	return priv->metadata_manager;
-#else
-	g_assert_not_reached ();
-	return NULL;
-#endif
-}
-
-
 GMenuModel *
 _gedit_app_get_hamburger_menu (GeditApp *app)
 {
