@@ -21,24 +21,18 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include "gedit-document.h"
 #include "gedit-document-private.h"
 
 #include <string.h>
 #include <glib/gi18n.h>
+#include <tepl/tepl.h>
 
-#include "gedit-app.h"
-#include "gedit-app-private.h"
 #include "gedit-settings.h"
 #include "gedit-debug.h"
 #include "gedit-utils.h"
-#include "gedit-metadata-manager.h"
-
-#define METADATA_QUERY "metadata::*"
 
 #define NO_LANGUAGE_NAME "_NORMAL_"
 
@@ -53,12 +47,12 @@ typedef struct
 {
 	GtkSourceFile *file;
 
+	/* Used only internally for the TeplFileMetadata. */
+	TeplFile *tepl_file;
+
 	GSettings   *editor_settings;
 
 	gint 	     untitled_number;
-	gchar       *short_name;
-
-	GFileInfo   *metadata_info;
 
 	gchar	    *content_type;
 
@@ -69,12 +63,9 @@ typedef struct
 	 */
 	GtkSourceSearchContext *search_context;
 
-	GeditMetadataManager *metadata_manager;
-
 	guint user_action;
 
 	guint language_set_by_user : 1;
-	guint use_gvfs_metadata : 1;
 
 	/* The search is empty if there is no search context, or if the
 	 * search text is empty. It is used for the sensitivity of some menu
@@ -94,9 +85,7 @@ enum
 	PROP_SHORTNAME,
 	PROP_CONTENT_TYPE,
 	PROP_MIME_TYPE,
-	PROP_READ_ONLY,
 	PROP_EMPTY_SEARCH,
-	PROP_USE_GVFS_METADATA,
 	LAST_PROP
 };
 
@@ -207,18 +196,17 @@ gedit_document_dispose (GObject *object)
 	/* Metadata must be saved here and not in finalize because the language
 	 * is gone by the time finalize runs.
 	 */
-	if (priv->file != NULL)
+	if (priv->tepl_file != NULL)
 	{
 		save_metadata (doc);
 
-		g_object_unref (priv->file);
-		priv->file = NULL;
+		g_object_unref (priv->tepl_file);
+		priv->tepl_file = NULL;
 	}
 
+	g_clear_object (&priv->file);
 	g_clear_object (&priv->editor_settings);
-	g_clear_object (&priv->metadata_info);
 	g_clear_object (&priv->search_context);
-	g_clear_object (&priv->metadata_manager);
 
 	G_OBJECT_CLASS (gedit_document_parent_class)->dispose (object);
 }
@@ -238,7 +226,6 @@ gedit_document_finalize (GObject *object)
 	}
 
 	g_free (priv->content_type);
-	g_free (priv->short_name);
 
 	G_OBJECT_CLASS (gedit_document_parent_class)->finalize (object);
 }
@@ -268,18 +255,10 @@ gedit_document_get_property (GObject    *object,
 			g_value_take_string (value, gedit_document_get_mime_type (doc));
 			break;
 
-		case PROP_READ_ONLY:
-			g_value_set_boolean (value, gtk_source_file_is_readonly (priv->file));
-			break;
-
 		case PROP_EMPTY_SEARCH:
 			g_value_set_boolean (value, priv->empty_search);
 			break;
 
-		case PROP_USE_GVFS_METADATA:
-			g_value_set_boolean (value, priv->use_gvfs_metadata);
-			break;
-
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 			break;
@@ -293,24 +272,13 @@ gedit_document_set_property (GObject      *object,
 			     GParamSpec   *pspec)
 {
 	GeditDocument *doc = GEDIT_DOCUMENT (object);
-	GeditDocumentPrivate *priv = gedit_document_get_instance_private (doc);
 
 	switch (prop_id)
 	{
-		case PROP_SHORTNAME:
-			G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
-			gedit_document_set_short_name_for_display (doc, g_value_get_string (value));
-			G_GNUC_END_IGNORE_DEPRECATIONS;
-			break;
-
 		case PROP_CONTENT_TYPE:
 			set_content_type (doc, g_value_get_string (value));
 			break;
 
-		case PROP_USE_GVFS_METADATA:
-			priv->use_gvfs_metadata = g_value_get_boolean (value);
-			break;
-
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 			break;
@@ -384,15 +352,6 @@ gedit_document_constructed (GObject *object)
 
 	priv = gedit_document_get_instance_private (doc);
 
-	if (!priv->use_gvfs_metadata)
-	{
-		GeditMetadataManager *metadata_manager;
-
-		metadata_manager = _gedit_app_get_metadata_manager (GEDIT_APP (g_application_get_default ()));
-		g_assert (GEDIT_IS_METADATA_MANAGER (metadata_manager));
-		priv->metadata_manager = g_object_ref (metadata_manager);
-	}
-
 	/* Bind construct properties. */
 	g_settings_bind (priv->editor_settings,
 			 GEDIT_SETTINGS_ENSURE_TRAILING_NEWLINE,
@@ -433,7 +392,7 @@ gedit_document_class_init (GeditDocumentClass *klass)
 		                     "Short Name",
 		                     "The document's short name",
 		                     NULL,
-		                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+		                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
 	/**
 	 * GeditDocument:content-type:
@@ -459,20 +418,6 @@ gedit_document_class_init (GeditDocumentClass *klass)
 		                     "text/plain",
 		                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
-	/**
-	 * GeditDocument:read-only:
-	 *
-	 * Whether the document is read-only or not.
-	 *
-	 * Deprecated: 3.18: Use the #GtkSourceFile API.
-	 */
-	properties[PROP_READ_ONLY] =
-		g_param_spec_boolean ("read-only",
-		                      "Read Only",
-		                      "Whether the document is read-only or not",
-		                      FALSE,
-		                      G_PARAM_READABLE | G_PARAM_STATIC_STRINGS | G_PARAM_DEPRECATED);
-
 	/**
 	 * GeditDocument:empty-search:
 	 *
@@ -488,25 +433,6 @@ gedit_document_class_init (GeditDocumentClass *klass)
 		                      TRUE,
 		                      G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
-	/**
-	 * GeditDocument:use-gvfs-metadata:
-	 *
-	 * Whether to use GVFS metadata. If %FALSE, use the gedit metadata
-	 * manager that stores the metadata in an XML file in the user cache
-	 * directory.
-	 *
-	 * <warning>
-	 * The property is used internally by gedit. It must not be used in a
-	 * gedit plugin. The property can be modified or removed at any time.
-	 * </warning>
-	 */
-	properties[PROP_USE_GVFS_METADATA] =
-		g_param_spec_boolean ("use-gvfs-metadata",
-		                      "Use GVFS metadata",
-		                      "",
-		                      TRUE,
-		                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
-
 	g_object_class_install_properties (object_class, LAST_PROP, properties);
 
 	/* This signal is used to update the cursor position in the statusbar,
@@ -535,8 +461,6 @@ gedit_document_class_init (GeditDocumentClass *klass)
 	 * Before gedit 3.14 this signal contained parameters to configure the
 	 * file loading (the location, encoding, etc). Plugins should not need
 	 * those parameters.
-	 *
-	 * Since: 2.22
 	 */
 	document_signals[LOAD] =
 		g_signal_new ("load",
@@ -574,8 +498,6 @@ gedit_document_class_init (GeditDocumentClass *klass)
 	 * Before gedit 3.14 this signal contained parameters to configure the
 	 * file saving (the location, encoding, etc). Plugins should not need
 	 * those parameters.
-	 *
-	 * Since: 2.20
 	 */
 	document_signals[SAVE] =
 		g_signal_new ("save",
@@ -727,10 +649,6 @@ guess_language (GeditDocument *doc)
 		{
 			basename = g_file_get_basename (location);
 		}
-		else if (priv->short_name != NULL)
-		{
-			basename = g_strdup (priv->short_name);
-		}
 
 		language = gtk_source_language_manager_guess_language (manager,
 								       basename,
@@ -788,61 +706,45 @@ on_location_changed (GtkSourceFile *file,
 		priv->untitled_number = 0;
 	}
 
-	if (priv->short_name == NULL)
-	{
-		g_object_notify_by_pspec (G_OBJECT (doc), properties[PROP_SHORTNAME]);
-	}
+	g_object_notify_by_pspec (G_OBJECT (doc), properties[PROP_SHORTNAME]);
+}
+
+static void
+on_tepl_location_changed (TeplFile      *file,
+			  GParamSpec    *pspec,
+			  GeditDocument *doc)
+{
+	TeplFileMetadata *metadata;
+	GError *error = NULL;
 
 	/* Load metadata for this location: we load sync since metadata is
 	 * always local so it should be fast and we need the information
 	 * right after the location was set.
+	 * TODO: do async I/O for the metadata.
 	 */
-	if (priv->use_gvfs_metadata && location != NULL)
+	metadata = tepl_file_get_file_metadata (file);
+	tepl_file_metadata_load (metadata, NULL, &error);
+
+	if (error != NULL)
 	{
-		GError *error = NULL;
-
-		if (priv->metadata_info != NULL)
+		/* Do not complain about metadata if we are opening a
+		 * non existing file.
+		 * TODO: we should know beforehand whether the file exists or
+		 * not, and load the metadata only when needed (after loading
+		 * the file content, for example).
+		 */
+		if (!g_error_matches (error, G_FILE_ERROR, G_FILE_ERROR_ISDIR) &&
+		    !g_error_matches (error, G_FILE_ERROR, G_FILE_ERROR_NOTDIR) &&
+		    !g_error_matches (error, G_FILE_ERROR, G_FILE_ERROR_NOENT) &&
+		    !g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND))
 		{
-			g_object_unref (priv->metadata_info);
+			g_warning ("Loading metadata failed: %s", error->message);
 		}
 
-		priv->metadata_info = g_file_query_info (location,
-		                                         METADATA_QUERY,
-		                                         G_FILE_QUERY_INFO_NONE,
-		                                         NULL,
-		                                         &error);
-
-		if (error != NULL)
-		{
-			/* Do not complain about metadata if we are opening a
-			 * non existing file.
-			 */
-			if (!g_error_matches (error, G_FILE_ERROR, G_FILE_ERROR_ISDIR) &&
-			    !g_error_matches (error, G_FILE_ERROR, G_FILE_ERROR_NOTDIR) &&
-			    !g_error_matches (error, G_FILE_ERROR, G_FILE_ERROR_NOENT) &&
-			    !g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND))
-			{
-				g_warning ("%s", error->message);
-			}
-
-			g_error_free (error);
-		}
-
-		if (priv->metadata_info == NULL)
-		{
-			priv->metadata_info = g_file_info_new ();
-		}
+		g_clear_error (&error);
 	}
 }
 
-static void
-on_readonly_changed (GtkSourceFile *file,
-		     GParamSpec    *pspec,
-		     GeditDocument *doc)
-{
-	g_object_notify_by_pspec (G_OBJECT (doc), properties[PROP_READ_ONLY]);
-}
-
 static void
 gedit_document_init (GeditDocument *doc)
 {
@@ -862,7 +764,6 @@ gedit_document_init (GeditDocument *doc)
 	g_get_current_time (&priv->time_of_last_save_or_load);
 
 	priv->file = gtk_source_file_new ();
-	priv->metadata_info = g_file_info_new ();
 
 	g_signal_connect_object (priv->file,
 				 "notify::location",
@@ -870,12 +771,19 @@ gedit_document_init (GeditDocument *doc)
 				 doc,
 				 0);
 
-	g_signal_connect_object (priv->file,
-				 "notify::read-only",
-				 G_CALLBACK (on_readonly_changed),
+	priv->tepl_file = tepl_file_new ();
+
+	g_signal_connect_object (priv->tepl_file,
+				 "notify::location",
+				 G_CALLBACK (on_tepl_location_changed),
 				 doc,
 				 0);
 
+	/* For using TeplFileMetadata we only need the TeplFile:location. */
+	g_object_bind_property (priv->file, "location",
+				priv->tepl_file, "location",
+				G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
+
 	g_settings_bind (priv->editor_settings,
 	                 GEDIT_SETTINGS_MAX_UNDO_ACTIONS,
 	                 doc,
@@ -909,17 +817,7 @@ gedit_document_init (GeditDocument *doc)
 GeditDocument *
 gedit_document_new (void)
 {
-	gboolean use_gvfs_metadata;
-
-#ifdef ENABLE_GVFS_METADATA
-	use_gvfs_metadata = TRUE;
-#else
-	use_gvfs_metadata = FALSE;
-#endif
-
-	return g_object_new (GEDIT_TYPE_DOCUMENT,
-			     "use-gvfs-metadata", use_gvfs_metadata,
-			     NULL);
+	return g_object_new (GEDIT_TYPE_DOCUMENT, NULL);
 }
 
 static gchar *
@@ -1030,32 +928,6 @@ set_content_type (GeditDocument *doc,
 	}
 }
 
-/**
- * gedit_document_get_location:
- * @doc: a #GeditDocument
- *
- * Returns: (allow-none) (transfer full): a copy of the internal #GFile
- *
- * Deprecated: 3.14: use gtk_source_file_get_location() instead. Attention,
- * gedit_document_get_location() has a transfer full for the return value, while
- * gtk_source_file_get_location() has a transfer none.
- */
-GFile *
-gedit_document_get_location (GeditDocument *doc)
-{
-	GeditDocumentPrivate *priv;
-	GFile *location;
-
-	priv = gedit_document_get_instance_private (doc);
-
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), NULL);
-
-	location = gtk_source_file_get_location (priv->file);
-
-	return location != NULL ? g_object_ref (location) : NULL;
-}
-
-
 /**
  * gedit_document_get_uri_for_display:
  * @doc: a #GeditDocument.
@@ -1103,11 +975,7 @@ gedit_document_get_short_name_for_display (GeditDocument *doc)
 
 	location = gtk_source_file_get_location (priv->file);
 
-	if (priv->short_name != NULL)
-	{
-		return g_strdup (priv->short_name);
-	}
-	else if (location == NULL)
+	if (location == NULL)
 	{
 		return g_strdup_printf (_("Untitled Document %d"),
 					priv->untitled_number);
@@ -1118,30 +986,6 @@ gedit_document_get_short_name_for_display (GeditDocument *doc)
 	}
 }
 
-/**
- * gedit_document_set_short_name_for_display:
- * @doc:
- * @short_name: (allow-none):
- *
- * Deprecated: 3.18: Unused function. The intent is to change the
- * #GeditDocument:shortname property to be read-only.
- */
-void
-gedit_document_set_short_name_for_display (GeditDocument *doc,
-                                           const gchar   *short_name)
-{
-	GeditDocumentPrivate *priv;
-
-	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
-
-	priv = gedit_document_get_instance_private (doc);
-
-	g_free (priv->short_name);
-	priv->short_name = g_strdup (short_name);
-
-	g_object_notify_by_pspec (G_OBJECT (doc), properties[PROP_SHORTNAME]);
-}
-
 gchar *
 gedit_document_get_content_type (GeditDocument *doc)
 {
@@ -1353,45 +1197,6 @@ gedit_document_is_untitled (GeditDocument *doc)
 	return gtk_source_file_get_location (priv->file) == NULL;
 }
 
-/**
- * gedit_document_is_local:
- * @doc: a #GeditDocument.
- *
- * Returns: whether the document is local.
- * Deprecated: 3.18: Use gtk_source_file_is_local() instead.
- */
-gboolean
-gedit_document_is_local (GeditDocument *doc)
-{
-	GeditDocumentPrivate *priv;
-
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), FALSE);
-
-	priv = gedit_document_get_instance_private (doc);
-
-	return gtk_source_file_is_local (priv->file);
-}
-
-/**
- * gedit_document_get_deleted:
- * @doc: a #GeditDocument.
- *
- * Returns: whether the file has been deleted.
- *
- * Deprecated: 3.18: Unused function.
- */
-gboolean
-gedit_document_get_deleted (GeditDocument *doc)
-{
-	GeditDocumentPrivate *priv;
-
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), FALSE);
-
-	priv = gedit_document_get_instance_private (doc);
-
-	return gtk_source_file_is_deleted (priv->file);
-}
-
 /*
  * Deletion and external modification is only checked for local files.
  */
@@ -1494,25 +1299,6 @@ gedit_document_get_language (GeditDocument *doc)
 	return gtk_source_buffer_get_language (GTK_SOURCE_BUFFER (doc));
 }
 
-/**
- * gedit_document_get_encoding:
- * @doc: a #GeditDocument.
- *
- * Returns: the encoding.
- * Deprecated: 3.14: use gtk_source_file_get_encoding() instead.
- */
-const GtkSourceEncoding *
-gedit_document_get_encoding (GeditDocument *doc)
-{
-	GeditDocumentPrivate *priv;
-
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), NULL);
-
-	priv = gedit_document_get_instance_private (doc);
-
-	return gtk_source_file_get_encoding (priv->file);
-}
-
 glong
 _gedit_document_get_seconds_since_last_save_or_load (GeditDocument *doc)
 {
@@ -1529,102 +1315,6 @@ _gedit_document_get_seconds_since_last_save_or_load (GeditDocument *doc)
 	return (current_time.tv_sec - priv->time_of_last_save_or_load.tv_sec);
 }
 
-/**
- * gedit_document_get_newline_type:
- * @doc: a #GeditDocument.
- *
- * Returns: the newline type.
- * Deprecated: 3.14: use gtk_source_file_get_newline_type() instead.
- */
-GtkSourceNewlineType
-gedit_document_get_newline_type (GeditDocument *doc)
-{
-	GeditDocumentPrivate *priv;
-
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), 0);
-
-	priv = gedit_document_get_instance_private (doc);
-
-	return gtk_source_file_get_newline_type (priv->file);
-}
-
-/**
- * gedit_document_get_compression_type:
- * @doc: a #GeditDocument.
- *
- * Returns: the compression type.
- * Deprecated: 3.14: use gtk_source_file_get_compression_type() instead.
- */
-GtkSourceCompressionType
-gedit_document_get_compression_type (GeditDocument *doc)
-{
-	GeditDocumentPrivate *priv;
-
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), 0);
-
-	priv = gedit_document_get_instance_private (doc);
-
-	return gtk_source_file_get_compression_type (priv->file);
-}
-
-static gchar *
-get_metadata_from_metadata_manager (GeditDocument *doc,
-				    const gchar   *key)
-{
-	GeditDocumentPrivate *priv;
-	GFile *location;
-
-	priv = gedit_document_get_instance_private (doc);
-
-	location = gtk_source_file_get_location (priv->file);
-
-	if (location != NULL)
-	{
-		return gedit_metadata_manager_get (priv->metadata_manager, location, key);
-	}
-
-	return NULL;
-}
-
-static gchar *
-get_metadata_from_gvfs (GeditDocument *doc,
-			const gchar   *key)
-{
-	GeditDocumentPrivate *priv;
-
-	priv = gedit_document_get_instance_private (doc);
-
-	if (priv->metadata_info != NULL &&
-	    g_file_info_has_attribute (priv->metadata_info, key) &&
-	    g_file_info_get_attribute_type (priv->metadata_info, key) == G_FILE_ATTRIBUTE_TYPE_STRING)
-	{
-		return g_strdup (g_file_info_get_attribute_string (priv->metadata_info, key));
-	}
-
-	return NULL;
-}
-
-static void
-set_gvfs_metadata (GFileInfo   *info,
-		   const gchar *key,
-		   const gchar *value)
-{
-	g_return_if_fail (G_IS_FILE_INFO (info));
-
-	if (value != NULL)
-	{
-		g_file_info_set_attribute_string (info, key, value);
-	}
-	else
-	{
-		/* Unset the key */
-		g_file_info_set_attribute (info,
-					   key,
-					   G_FILE_ATTRIBUTE_TYPE_INVALID,
-					   NULL);
-	}
-}
-
 /**
  * gedit_document_get_metadata:
  * @doc: a #GeditDocument
@@ -1639,18 +1329,20 @@ gedit_document_get_metadata (GeditDocument *doc,
 			     const gchar   *key)
 {
 	GeditDocumentPrivate *priv;
+	TeplFileMetadata *metadata;
 
 	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), NULL);
 	g_return_val_if_fail (key != NULL, NULL);
 
 	priv = gedit_document_get_instance_private (doc);
 
-	if (priv->use_gvfs_metadata)
+	if (priv->tepl_file == NULL)
 	{
-		return get_metadata_from_gvfs (doc, key);
+		return NULL;
 	}
 
-	return get_metadata_from_metadata_manager (doc, key);
+	metadata = tepl_file_get_file_metadata (priv->tepl_file);
+	return tepl_file_metadata_get (metadata, key);
 }
 
 /**
@@ -1668,84 +1360,57 @@ gedit_document_set_metadata (GeditDocument *doc,
 			     ...)
 {
 	GeditDocumentPrivate *priv;
-	GFile *location;
-	const gchar *key;
+	TeplFileMetadata *metadata;
 	va_list var_args;
-	GFileInfo *info = NULL;
+	const gchar *key;
+	GError *error = NULL;
 
 	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
 	g_return_if_fail (first_key != NULL);
 
 	priv = gedit_document_get_instance_private (doc);
 
-	location = gtk_source_file_get_location (priv->file);
-
-	/* With the metadata manager, can't set metadata for untitled documents.
-	 * With GVFS metadata, if the location is NULL the metadata is stored in
-	 * priv->metadata_info, so that it can be saved later if the document is
-	 * saved.
-	 */
-	if (!priv->use_gvfs_metadata && location == NULL)
+	if (priv->tepl_file == NULL)
 	{
 		return;
 	}
 
-	if (priv->use_gvfs_metadata)
-	{
-		info = g_file_info_new ();
-	}
-
+	metadata = tepl_file_get_file_metadata (priv->tepl_file);
 	va_start (var_args, first_key);
 
-	for (key = first_key; key; key = va_arg (var_args, const gchar *))
+	for (key = first_key; key != NULL; key = va_arg (var_args, const gchar *))
 	{
 		const gchar *value = va_arg (var_args, const gchar *);
-
-		if (priv->use_gvfs_metadata)
-		{
-			set_gvfs_metadata (info, key, value);
-			set_gvfs_metadata (priv->metadata_info, key, value);
-		}
-		else
-		{
-			gedit_metadata_manager_set (priv->metadata_manager, location, key, value);
-		}
+		tepl_file_metadata_set (metadata, key, value);
 	}
 
 	va_end (var_args);
 
-	if (priv->use_gvfs_metadata && location != NULL)
+	/* We save synchronously since metadata is always local so it should be
+	 * fast. Moreover this function can be called on application shutdown,
+	 * when the main loop has already exited, so an async operation would
+	 * not terminate.
+	 * https://bugzilla.gnome.org/show_bug.cgi?id=736591
+	 * TODO: do async I/O for the metadata.
+	 */
+	tepl_file_metadata_save (metadata, NULL, &error);
+
+	if (error != NULL)
 	{
-		GError *error = NULL;
-
-		/* We save synchronously since metadata is always local so it
-		 * should be fast. Moreover this function can be called on
-		 * application shutdown, when the main loop has already exited,
-		 * so an async operation would not terminate.
-		 * https://bugzilla.gnome.org/show_bug.cgi?id=736591
+		/* Do not complain about metadata if we are closing a document
+		 * for a non existing file.
+		 * TODO: we should know beforehand whether the file exists or
+		 * not, and save the metadata only when needed (after saving the
+		 * file content, for example).
 		 */
-		g_file_set_attributes_from_info (location,
-						 info,
-						 G_FILE_QUERY_INFO_NONE,
-						 NULL,
-						 &error);
-
-		if (error != NULL)
+		if (!g_error_matches (error, G_FILE_ERROR, G_FILE_ERROR_NOENT) &&
+		    !g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND))
 		{
-			/* Do not complain about metadata if we are closing a
-			 * document for a non existing file.
-			 */
-			if (!g_error_matches (error, G_FILE_ERROR, G_FILE_ERROR_NOENT) &&
-			    !g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND))
-			{
-				g_warning ("Set document metadata failed: %s", error->message);
-			}
-
-			g_error_free (error);
+			g_warning ("Saving metadata failed: %s", error->message);
 		}
-	}
 
-	g_clear_object (&info);
+		g_clear_error (&error);
+	}
 }
 
 static void
