@@ -24,6 +24,7 @@
 
 #include <string.h>
 #include <glib/gi18n.h>
+#include <tepl/tepl.h>
 
 /* For the workspace/viewport stuff */
 #ifdef GDK_WINDOWING_X11
@@ -45,6 +46,16 @@ widget_get_origin (GtkWidget *widget,
 	gdk_window_get_origin (window, x, y);
 }
 
+/**
+ * gedit_utils_menu_position_under_widget:
+ * @menu:
+ * @x:
+ * @y:
+ * @push_in:
+ * @user_data:
+ *
+ * Deprecated: 3.36: Use gtk_menu_popup_at_widget() instead.
+ */
 void
 gedit_utils_menu_position_under_widget (GtkMenu  *menu,
 					gint     *x,
@@ -214,123 +225,47 @@ gedit_warning (GtkWindow *parent, const gchar *format, ...)
 	gtk_widget_show (dialog);
 }
 
-/* the following functions are taken from eel */
-
-static gchar *
-gedit_utils_str_truncate (const gchar *string,
-			  guint        truncate_length,
-			  gboolean     middle)
-{
-	GString     *truncated;
-	guint        length;
-	guint        n_chars;
-	guint        num_left_chars;
-	guint        right_offset;
-	guint        delimiter_length;
-	const gchar *delimiter = "\342\200\246";
-
-	g_return_val_if_fail (string != NULL, NULL);
-
-	length = strlen (string);
-
-	g_return_val_if_fail (g_utf8_validate (string, length, NULL), NULL);
-
-	/* It doesnt make sense to truncate strings to less than
-	 * the size of the delimiter plus 2 characters (one on each
-	 * side)
-	 */
-	delimiter_length = g_utf8_strlen (delimiter, -1);
-	if (truncate_length < (delimiter_length + 2))
-	{
-		return g_strdup (string);
-	}
-
-	n_chars = g_utf8_strlen (string, length);
-
-	/* Make sure the string is not already small enough. */
-	if (n_chars <= truncate_length)
-	{
-		return g_strdup (string);
-	}
-
-	/* Find the 'middle' where the truncation will occur. */
-	if (middle)
-	{
-		num_left_chars = (truncate_length - delimiter_length) / 2;
-		right_offset = n_chars - truncate_length + num_left_chars + delimiter_length;
-
-		truncated = g_string_new_len (string,
-					      g_utf8_offset_to_pointer (string, num_left_chars) - string);
-		g_string_append (truncated, delimiter);
-		g_string_append (truncated, g_utf8_offset_to_pointer (string, right_offset));
-	}
-	else
-	{
-		num_left_chars = truncate_length - delimiter_length;
-		truncated = g_string_new_len (string,
-					      g_utf8_offset_to_pointer (string, num_left_chars) - string);
-		g_string_append (truncated, delimiter);
-	}
-
-	return g_string_free (truncated, FALSE);
-}
-
+/**
+ * gedit_utils_str_middle_truncate:
+ * @string:
+ * @truncate_length:
+ *
+ * Returns:
+ * Deprecated: 3.36: Use tepl_utils_str_middle_truncate() instead.
+ */
 gchar *
 gedit_utils_str_middle_truncate (const gchar *string,
 				 guint        truncate_length)
 {
-	return gedit_utils_str_truncate (string, truncate_length, TRUE);
+	return tepl_utils_str_middle_truncate (string, truncate_length);
 }
 
+/**
+ * gedit_utils_str_end_truncate:
+ * @string:
+ * @truncate_length:
+ *
+ * Returns:
+ * Deprecated: 3.36: Use tepl_utils_str_end_truncate() instead.
+ */
 gchar *
 gedit_utils_str_end_truncate (const gchar *string,
 			      guint        truncate_length)
 {
-	return gedit_utils_str_truncate (string, truncate_length, FALSE);
+	return tepl_utils_str_end_truncate (string, truncate_length);
 }
 
+/**
+ * gedit_utils_make_valid_utf8:
+ * @name:
+ *
+ * Returns:
+ * Deprecated: 3.36: Use g_utf8_make_valid() instead.
+ */
 gchar *
 gedit_utils_make_valid_utf8 (const char *name)
 {
-	GString *string;
-	const char *remainder, *invalid;
-	int remaining_bytes, valid_bytes;
-
-	g_return_val_if_fail (name != NULL, NULL);
-
-	string = NULL;
-	remainder = name;
-	remaining_bytes = strlen (name);
-
-	while (remaining_bytes != 0) {
-		if (g_utf8_validate (remainder, remaining_bytes, &invalid))
-		{
-			break;
-		}
-		valid_bytes = invalid - remainder;
-
-		if (string == NULL)
-		{
-			string = g_string_sized_new (remaining_bytes);
-		}
-		g_string_append_len (string, remainder, valid_bytes);
-		/* append U+FFFD REPLACEMENT CHARACTER */
-		g_string_append (string, "\357\277\275");
-
-		remaining_bytes -= valid_bytes + 1;
-		remainder = invalid + 1;
-	}
-
-	if (string == NULL)
-	{
-		return g_strdup (name);
-	}
-
-	g_string_append (string, remainder);
-
-	g_assert (g_utf8_validate (string->str, -1, NULL));
-
-	return g_string_free (string, FALSE);
+	return g_utf8_make_valid (name, -1);
 }
 
 static gchar *
@@ -352,7 +287,7 @@ uri_get_dirname (const gchar *uri)
 		return NULL;
 	}
 
-	res = gedit_utils_replace_home_dir_with_tilde (str);
+	res = tepl_utils_replace_home_dir_with_tilde (str);
 
 	g_free (str);
 
@@ -433,49 +368,17 @@ gedit_utils_location_get_dirname_for_display (GFile *location)
 	return res;
 }
 
+/**
+ * gedit_utils_replace_home_dir_with_tilde:
+ * @uri:
+ *
+ * Returns:
+ * Deprecated: 3.36: Use tepl_utils_replace_home_dir_with_tilde() instead.
+ */
 gchar *
 gedit_utils_replace_home_dir_with_tilde (const gchar *uri)
 {
-	gchar *tmp;
-	gchar *home;
-
-	g_return_val_if_fail (uri != NULL, NULL);
-
-	/* Note that g_get_home_dir returns a const string */
-	tmp = (gchar *)g_get_home_dir ();
-
-	if (tmp == NULL)
-		return g_strdup (uri);
-
-	home = g_filename_to_utf8 (tmp, -1, NULL, NULL, NULL);
-	if (home == NULL)
-		return g_strdup (uri);
-
-	if (strcmp (uri, home) == 0)
-	{
-		g_free (home);
-
-		return g_strdup ("~/");
-	}
-
-	tmp = home;
-	home = g_strdup_printf ("%s/", tmp);
-	g_free (tmp);
-
-	if (g_str_has_prefix (uri, home))
-	{
-		gchar *res;
-
-		res = g_strdup_printf ("~/%s", uri + strlen (home));
-
-		g_free (home);
-
-		return res;
-	}
-
-	g_free (home);
-
-	return g_strdup (uri);
+	return tepl_utils_replace_home_dir_with_tilde (uri);
 }
 
 /* the following two functions are courtesy of galeon */
@@ -846,7 +749,7 @@ gedit_utils_basename_for_display (GFile *location)
 
 		if  (hn != NULL)
 		{
-			hn_utf8 = gedit_utils_make_valid_utf8 (hn);
+			hn_utf8 = g_utf8_make_valid (hn, -1);
 		}
 		else
 		{
