@@ -31,33 +31,11 @@ G_BEGIN_DECLS
 #define GBOOLEAN_TO_POINTER(i) (GINT_TO_POINTER ((i) ? 2 : 1))
 #define GPOINTER_TO_BOOLEAN(i) ((gboolean) ((GPOINTER_TO_INT(i) == 2) ? TRUE : FALSE))
 
-/**
- * IS_VALID_BOOLEAN:
- * @v: a gboolean.
- *
- * Deprecated: 3.18
- */
-#ifndef GEDIT_DISABLE_DEPRECATED
-#define IS_VALID_BOOLEAN(v) (((v == TRUE) || (v == FALSE)) ? TRUE : FALSE)
-#endif
-
 enum { GEDIT_ALL_WORKSPACES = 0xffffffff };
 
-void                       gedit_utils_menu_position_under_widget             (GtkMenu         *menu,
-                                                                               gint            *x,
-                                                                               gint            *y,
-                                                                               gboolean        *push_in,
-                                                                               gpointer         user_data);
 gboolean                   gedit_utils_menu_position_under_tree_view          (GtkTreeView     *tree_view,
                                                                                GdkRectangle    *rect);
 
-G_DEPRECATED
-gchar                     *gedit_utils_escape_underscores                     (const gchar     *text,
-                                                                               gssize           length);
-gchar                     *gedit_utils_str_middle_truncate                    (const gchar     *string,
-                                                                               guint            truncate_length);
-gchar                     *gedit_utils_str_end_truncate                       (const gchar     *string,
-                                                                               guint            truncate_length);
 void                       gedit_utils_set_atk_name_description               (GtkWidget       *widget,
                                                                                const gchar     *name,
                                                                                const gchar     *description);
@@ -67,14 +45,8 @@ void                       gedit_utils_set_atk_relation                       (G
 void                       gedit_warning                                       (GtkWindow      *parent,
                                                                                 const gchar    *format,
                                                                                 ...) G_GNUC_PRINTF(2, 3);
-gchar                     *gedit_utils_make_valid_utf8                         (const char     *name);
 
-
-/* Note that this function replace home dir with ~ */
-G_DEPRECATED
-gchar                     *gedit_utils_uri_get_dirname                         (const char     *uri);
 gchar                     *gedit_utils_location_get_dirname_for_display        (GFile          *location);
-gchar                     *gedit_utils_replace_home_dir_with_tilde             (const gchar    *uri);
 guint                      gedit_utils_get_current_workspace                   (GdkScreen      *screen);
 guint                      gedit_utils_get_window_workspace                    (GtkWindow      *gtkwindow);
 void                       gedit_utils_get_current_viewport                    (GdkScreen      *screen,
@@ -83,40 +55,39 @@ void                       gedit_utils_get_current_viewport                    (
 gboolean                   gedit_utils_is_valid_location                       (GFile          *location);
 
 
-G_DEPRECATED
-gboolean                   gedit_utils_get_ui_objects                          (const gchar    *filename,
-                                                                                gchar         **root_objects,
-                                                                                GtkWidget     **error_widget,
-                                                                                const gchar    *object_name,
-                                                                                ...) G_GNUC_NULL_TERMINATED;
-
-
-G_DEPRECATED
-gboolean                   gedit_utils_get_ui_objects_with_translation_domain  (const gchar  *filename,
-                                                                                const gchar  *translation_domain,
-                                                                                gchar       **root_objects,
-                                                                                GtkWidget   **error_widget,
-                                                                                const gchar  *object_name,
-                                                                                ...) G_GNUC_NULL_TERMINATED;
-
-G_DEPRECATED
-gchar                     *gedit_utils_make_canonical_uri_from_shell_arg      (const gchar  *str);
 gchar                     *gedit_utils_basename_for_display                   (GFile        *location);
 gboolean                   gedit_utils_decode_uri                             (const gchar  *uri,
                                                                                gchar       **scheme,
                                                                                gchar       **user,
-                                                                               gchar       **port,
                                                                                gchar       **host,
+                                                                               gchar       **port,
                                                                                gchar       **path);
 
-
-
 /* Turns data from a drop into a list of well formatted uris */
 gchar                    **gedit_utils_drop_get_uris                          (GtkSelectionData     *selection_data);
+
 GtkSourceCompressionType   gedit_utils_get_compression_type_from_content_type (const gchar          *content_type);
 gchar                     *gedit_utils_set_direct_save_filename               (GdkDragContext       *context);
 const gchar               *gedit_utils_newline_type_to_string                 (GtkSourceNewlineType  newline_type);
 
+G_DEPRECATED_FOR (g_utf8_make_valid)
+gchar                     *gedit_utils_make_valid_utf8                         (const char     *name);
+
+G_DEPRECATED_FOR (tepl_utils_str_middle_truncate)
+gchar                     *gedit_utils_str_middle_truncate                    (const gchar     *string,
+                                                                               guint            truncate_length);
+G_DEPRECATED_FOR (tepl_utils_str_end_truncate)
+gchar                     *gedit_utils_str_end_truncate                       (const gchar     *string,
+                                                                               guint            truncate_length);
+G_DEPRECATED_FOR (tepl_utils_replace_home_dir_with_tilde)
+gchar                     *gedit_utils_replace_home_dir_with_tilde             (const gchar    *uri);
+
+G_DEPRECATED_FOR (gtk_menu_popup_at_widget)
+void                       gedit_utils_menu_position_under_widget             (GtkMenu         *menu,
+                                                                               gint            *x,
+                                                                               gint            *y,
+                                                                               gboolean        *push_in,
+                                                                               gpointer         user_data);
 
 G_END_DECLS
 
