@@ -18,24 +18,21 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include "gedit-app.h"
-#ifdef OS_OSX
-#include "gedit-app-osx.h"
+
+#if defined OS_OSX
+#  include "gedit-app-osx.h"
+#elif defined G_OS_WIN32
+#  include "gedit-app-win32.h"
 #else
-#ifdef G_OS_WIN32
-#include "gedit-app-win32.h"
-#else
-#include "gedit-app-x11.h"
-#endif
+#  include "gedit-app-x11.h"
 #endif
 
-#include <glib.h>
 #include <locale.h>
 #include <libintl.h>
+#include <tepl/tepl.h>
 
 #include "gedit-dirs.h"
 #include "gedit-debug.h"
@@ -100,7 +97,21 @@ gedit_w32_unload_private_dll (void)
 		libgedit_dll = NULL;
 	}
 }
-#endif
+#endif /* G_OS_WIN32 */
+
+static void
+setup_i18n (void)
+{
+	const gchar *dir;
+
+	setlocale (LC_ALL, "");
+
+	dir = gedit_dirs_get_gedit_locale_dir ();
+	bindtextdomain (GETTEXT_PACKAGE, dir);
+
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+}
 
 int
 main (int argc, char *argv[])
@@ -108,12 +119,10 @@ main (int argc, char *argv[])
 	GType type;
 	GeditApp *app;
 	gint status;
-	const gchar *dir;
 
-#ifdef OS_OSX
+#if defined OS_OSX
 	type = GEDIT_TYPE_APP_OSX;
-#else
-#ifdef G_OS_WIN32
+#elif defined G_OS_WIN32
 	if (!gedit_w32_load_private_dll ())
 	{
 		return 1;
@@ -122,31 +131,23 @@ main (int argc, char *argv[])
 	type = GEDIT_TYPE_APP_WIN32;
 #else
 	type = GEDIT_TYPE_APP_X11;
-#endif
 #endif
 
 	/* NOTE: we should not make any calls to the gedit api before the
 	 * private library is loaded */
 	gedit_dirs_init ();
 
-	/* Setup locale/gettext */
-	setlocale (LC_ALL, "");
+	setup_i18n ();
+	tepl_init ();
 
-	dir = gedit_dirs_get_gedit_locale_dir ();
-	bindtextdomain (GETTEXT_PACKAGE, dir);
-
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	textdomain (GETTEXT_PACKAGE);
+	/* https://honk.sigxcpu.org/con/GTK__and_the_application_id.html */
+	g_set_prgname ("org.gnome.gedit");
 
 	app = g_object_new (type,
 	                    "application-id", "org.gnome.gedit",
 	                    "flags", G_APPLICATION_HANDLES_COMMAND_LINE | G_APPLICATION_HANDLES_OPEN,
 	                    NULL);
 
-
-	/* https://honk.sigxcpu.org/con/GTK__and_the_application_id.html */
-	g_set_prgname("org.gnome.gedit");
-
 	status = g_application_run (G_APPLICATION (app), argc, argv);
 
 	/* Break reference cycles caused by the PeasExtensionSet
@@ -163,6 +164,8 @@ main (int argc, char *argv[])
 		                     G_OBJECT (app)->ref_count);
 	}
 
+	tepl_finalize ();
+
 #ifdef G_OS_WIN32
 	gedit_w32_unload_private_dll ();
 #endif
